powered by
Generates Fortran code to return the current values of forcing functions based on interpolation in tabulated time series data.
forcingFunctions(x)
A character string holding generated Fortran code. Must be written to disk, e.g. using write, prior to compilation.
write
Data frame with colums 'name', 'file', 'column', 'mode', 'default'. See below for expected entries.
David Kneis [email protected]